<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ShowDesktop</name>
    <message>
        <location filename="../showdesktop.cpp" line="44"/>
        <source>Show desktop</source>
        <translation>Rodyti darbalaukį</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="66"/>
        <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>Rodyti darbalaukį: Visuotinis spartusis klavišas &quot;%1&quot; negali būti užregistruotas</translation>
    </message>
    <message>
        <location filename="../showdesktop.cpp" line="51"/>
        <source>Show Desktop</source>
        <translation>Rodyti darbalaukį</translation>
    </message>
</context>
</TS>
